@@ -189,8 +189,8 @@ AIRSIS <- list(unitTypes=list(DATARAM=21,
 #' @details
 #' The \code{AQI} object contains english language text.
 #'
-#' AQI breaks and colors are defined in
-#' \url{https://airnow.gov/sites/default/files/2018-09/aqi-technical-assistance-document-sept-2018_0.pdf}
+#' AQI breaks and colors are defined at
+#' \url{https://docs.airnowapi.org/aq101}
 #' @note
 #' The low end of each break category is used as the breakpoint.
 #' @seealso \code{\link{AQI_en}} \code{\link{AQI_es}}
@@ -203,6 +203,7 @@ AQI <- list(
              grDevices::rgb(255/255,0,0),
              grDevices::rgb(143/255,63/255,151/255),
              grDevices::rgb(126/255,0,35/255)),
+  mv4Colors = c("#2ecc71", "#f1c40f", "#e67e22", "#e74c3c", "#9b59b6", "#8c3a3a"),
   names = c('Good','Moderate','USG','Unhealthy','Very Unhealthy','Hazardous'),
   actions = c(
     'None.',
@@ -227,8 +228,8 @@ AQI <- list(
 #' The \code{AQI_es} object contains english language text. It is equalivalent to the
 #' \code{AQI} object and provided for consistency with other language versions.
 #'
-#' AQI breaks and colors are defined in
-#' \url{https://airnow.gov/sites/default/files/2018-09/aqi-technical-assistance-document-sept-2018_0.pdf}
+#' AQI breaks and colors are defined at
+#' \url{https://docs.airnowapi.org/aq101}
 #' @note
 #' The low end of each break category is used as the breakpoint.
 #' @seealso \code{\link{AQI}} \code{\link{AQI_es}}
@@ -241,6 +242,7 @@ AQI_en <- list(
              grDevices::rgb(255/255,0,0),
              grDevices::rgb(143/255,63/255,151/255),
              grDevices::rgb(126/255,0,35/255)),
+  mv4Colors = c("#2ecc71", "#f1c40f", "#e67e22", "#e74c3c", "#9b59b6", "#8c3a3a"),
   names = c('Good','Moderate','USG','Unhealthy','Very Unhealthy','Hazardous'),
   actions = c(
     'None.',
@@ -252,7 +254,7 @@ AQI_en <- list(
   )
 )
 
-#' AQI breaks and associated names and colors (spanish language)
+#' AQI breaks and associated names and colors (Spanish language)
 #'
 #' @export
 #' @docType data
@@ -264,8 +266,8 @@ AQI_en <- list(
 #' @details
 #' The \code{AQI_es} object contains spanish language text.
 #'
-#' AQI breaks and colors are defined in
-#' \url{https://airnow.gov/sites/default/files/2018-09/aqi-technical-assistance-document-sept-2018_0.pdf}
+#' AQI breaks and colors are defined at
+#' \url{https://docs.airnowapi.org/aq101}
 #' @note
 #' The low end of each break category is used as the breakpoint.
 #' @seealso \code{\link{AQI_en}} \code{\link{AQI}}
@@ -278,6 +280,7 @@ AQI_es <- list(
              grDevices::rgb(255/255,0,0),
              grDevices::rgb(143/255,63/255,151/255),
              grDevices::rgb(126/255,0,35/255)),
+  mv4Colors = c("#2ecc71", "#f1c40f", "#e67e22", "#e74c3c", "#9b59b6", "#8c3a3a"),
   names = c('Buena','Moderada','IGS','Insalubre','Muy insalubre','Peligrosa'),
   # NOTE:  R packages require that unicode characters be escaped.
   actions = c(
