@@ -1,6 +1,9 @@
 #' @keywords internal
 #' @export
+#' @import MazamaCoreUtils
+#'
 #' @importFrom utils installed.packages
+#'
 #' @title Add Elevation Data to a Dataframe
 #' @param df dataframe with geolocation information (\emph{e.g.} created by \code{wrcc_qualityControl()} or \code{airsis_qualityControl})
 #' @param lonVar name of longitude variable in the incoming dataframe
@@ -11,7 +14,12 @@
 #' @return Input dataframe with (possibly) additional column: \code{elevation}.
 #' @references \url{https://nationalmap.gov/epqs/}
 
-addUSGSElevation <- function(df, lonVar="longitude", latVar="latitude", existingMeta=NULL) {
+addUSGSElevation <- function(
+  df,
+  lonVar = "longitude",
+  latVar = "latitude",
+  existingMeta = NULL
+) {
 
   logger.debug(" ----- addUSGSElevation() ----- ")
 
@@ -40,7 +48,7 @@ addUSGSElevation <- function(df, lonVar="longitude", latVar="latitude", existing
     # Sanity check -- make sure df does not have class "tbl_df" or "tibble"
     df <- as.data.frame(df, stringsAsFactors=FALSE)
 
-    for (i in 1:nrow(df)) {
+    for ( i in seq_len(nrow(df)) ) {
       monitorID <- df[i,'monitorID']
       if ( monitorID %in% existingMeta$monitorID ) {
         df$elevation[i] <- existingMeta[monitorID,'elevation']
@@ -55,12 +63,12 @@ addUSGSElevation <- function(df, lonVar="longitude", latVar="latitude", existing
 
     # https://nationalmap.gov/epqs/pqs.php?x=-123.4&y=47.24&units=Meters&output=json
 
-    logger.debug("Getting USGS elevation data for %s location(s)", nrow(df))
+    logger.trace("Getting USGS elevation data for %s location(s)", nrow(df))
 
     # Create url
     url <- httr::parse_url("https://nationalmap.gov/epqs/pqs.php")
 
-    for ( i in 1:nrow(df) ) {
+    for ( i in seq_len(nrow(df)) ) {
 
       lon <- lons[i]
       lat <- lats[i]
